const posibleTags = ['h1', 'h2', 'h3', 'h4'];
const defaultOptions = {
    tags: ['h2', 'h3', 'h4'],
};
const headersPlugin = (opts) => ({
    register(textarena) {
        const options = Object.assign(Object.assign({}, defaultOptions), (opts || {}));
        options.tags.forEach((type) => {
            if (posibleTags.includes(type)) {
                const number = parseInt(type[1], 10);
                const command = `convert-to-header${number}`;
                const name = `header${number}`;
                const tag = `H${number}`;
                const title = `Header ${number}`;
                const icon = `<b>H${number}</b>`;
                const shortcut = `Alt + Digit${number}`;
                const paragraph = textarena.getDefaultTextArena();
                if (!paragraph) {
                    throw new Error('Default Arena for text not found');
                }
                const arena = textarena.registerArena({
                    name,
                    tag,
                    attributes: {},
                    hasText: true,
                    nextArena: paragraph,
                }, [
                    {
                        tag,
                        attributes: [],
                    },
                ], [textarena.getRootArenaName()]);
                textarena.registerCommand(command, (ta, selection) => ta.applyArenaToSelection(selection, arena));
                textarena.registerShortcut(shortcut, command);
                textarena.registerTool({
                    name,
                    title,
                    icon,
                    shortcut,
                    hint: number.toString(),
                    command,
                    checkStatus: (node) => node.arena === arena,
                });
                textarena.registerCreator({
                    name,
                    title,
                    icon,
                    shortcut,
                    hint: number.toString(),
                    command,
                    canShow: (node) => textarena.isAllowedNode(node, arena),
                });
            }
        });
    },
});
export default headersPlugin;
//# sourceMappingURL=headersPlugin.js.map